import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:get/get.dart';
import 'package:urban/controller/dashBoard_controller.dart';
import 'package:urban/screen/booking/booking_screen.dart';
import 'package:urban/screen/bottom_navigation/navigation_screen.dart';
import 'package:urban/screen/home/home_screen.dart';
import 'package:urban/screen/message/message_screen.dart';
import 'package:urban/screen/profile/profile_screen.dart';
import 'package:urban/utills/color.dart';
import 'package:urban/utills/images.dart';

class DashBoardScreen extends StatelessWidget {
  final DashBoardController dashBoardController = Get.put(DashBoardController());

  final Map navigatorKeys = {
    1: GlobalKey(),
    0: GlobalKey(),
    2: GlobalKey(),
    3: GlobalKey()
  };

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body:Obx(
        ()=> WillPopScope(
          onWillPop: () async {
            if (dashBoardController.tabIndex.value == 0) return true;

            dashBoardController.tabIndex.value = 0;

            return false;
          },
          child: IndexedStack(
            index: dashBoardController.tabIndex.value,
            children: [
              NavigatorPage(
                child: HomeScreen(),
                navigatorKey: navigatorKeys[0],
                title: "Home",
              ),
              NavigatorPage(
                child: BookingScreen(),
                navigatorKey: navigatorKeys[1],
                title: "Like",
              ),
              NavigatorPage(
                child: MessageScreen(),
                navigatorKey: navigatorKeys[2],
                title: "Cart",
              ),
              NavigatorPage(
                child: ProfileScreen(),
                navigatorKey: navigatorKeys[3],
                title: "Profile",
              ),
            ],
          ),
        ),
      ),
      bottomNavigationBar: Obx(
        ()=> WillPopScope(
          onWillPop: () async {
            return !await Navigator.maybePop(
                navigatorKeys[dashBoardController.tabIndex.value].currentState.context);
          },
          child: BottomNavigationBar(
            showUnselectedLabels: true,
            showSelectedLabels: true,
            selectedFontSize: 12,
            unselectedFontSize: 12,
            selectedLabelStyle: TextStyle(fontFamily: "RobotoMedium"),
            unselectedLabelStyle: TextStyle(fontFamily: "RobotoMedium"),
            selectedItemColor:  black,
            unselectedItemColor: black,
            type: BottomNavigationBarType.fixed,
            onTap: dashBoardController.changeTabIndex,
            currentIndex: dashBoardController.tabIndex.value,
            backgroundColor: white,

            items: [
              BottomNavigationBarItem(
                icon: Padding(
                  padding: const EdgeInsets.only(bottom: 5,top: 5),
                  child: SvgPicture.asset(homeIcon,color: black,),
                ),
                backgroundColor: white,
                activeIcon: Padding(
                  padding: const EdgeInsets.only(bottom: 3.0),
                  child: Container(
                    height: 30,
                    width: 60,
                    child: Padding(
                      padding: const EdgeInsets.all(5.0),
                      child: SvgPicture.asset(homeIcon),
                    ),
                    decoration: BoxDecoration(
                      color: blue,
                      borderRadius: BorderRadius.circular(20)
                    ),
                  ),
                ),
                label: 'Home',
                // backgroundColor: Color.fromRGBO(36, 54, 101, 1.0),
              ),
              BottomNavigationBarItem(
                icon: Padding(
                  padding: const EdgeInsets.only(top: 5.0,bottom: 5.0),
                  child: SvgPicture.asset(bookingIcon,color: black,),
                ),
                backgroundColor: white,
                activeIcon: Padding(
                  padding: const EdgeInsets.only(bottom: 3.0),
                  child: Container(
                    height: 28,
                    width: 55,
                    child: Padding(
                      padding: const EdgeInsets.all(4.0),
                      child: SvgPicture.asset(bookingIcon,color: white,),
                    ),
                    decoration: BoxDecoration(
                        color: blue,
                        borderRadius: BorderRadius.circular(20)
                    ),
                  ),
                ),
                label: 'Booking',
                // backgroundColor: Color.fromRGBO(36, 54, 101, 1.0),
              ),
              BottomNavigationBarItem(
                icon: Padding(
                  padding: const EdgeInsets.only(top: 5.0,bottom: 5.0),
                  child: SvgPicture.asset(messageIcon,color: black,),
                ),
                backgroundColor: white,
                activeIcon: Padding(
                  padding: const EdgeInsets.only(bottom: 3.0),
                  child: Container(
                    height: 28,
                    width: 55,
                    child: Padding(
                      padding: const EdgeInsets.all(5.0),
                      child: SvgPicture.asset(messageIcon,color: white,),
                    ),
                    decoration: BoxDecoration(
                        color: blue,
                        borderRadius: BorderRadius.circular(20)
                    ),
                  ),
                ),
                label: 'Message',
                // backgroundColor: Color.fromRGBO(36, 54, 101, 1.0),
              ),
              BottomNavigationBarItem(
                icon: Padding(
                  padding: const EdgeInsets.only(top: 5.0,bottom: 5.0),
                  child: SvgPicture.asset(profileIcon,color: black,),
                ),
                backgroundColor: white,
                activeIcon: Padding(
                  padding: const EdgeInsets.only(bottom: 3.0),
                  child: Container(
                    height: 28,
                    width: 55,
                    child: Padding(
                      padding: const EdgeInsets.all(5.0),
                      child: SvgPicture.asset(profileIcon,color: white,),
                    ),
                    decoration: BoxDecoration(
                        color: blue,
                        borderRadius: BorderRadius.circular(20)
                    ),
                  ),
                ),
                label: 'Profile',
                // backgroundColor: Color.fromRGBO(36, 54, 101, 1.0),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

