import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:get/get.dart';
import 'package:urban/screen/message/chatdetail_screen.dart';
import 'package:urban/utills/color.dart';
import 'package:urban/utills/common_widget.dart';
import 'package:urban/utills/images.dart';

class ConversationList extends StatefulWidget {
  final String name;
  final String messageText;
  final String imageUrl;
  final String time;
  final bool isMessageRead;
  final int pendingMessage;


  ConversationList(
      {required this.name,
      required this.messageText,
      required this.imageUrl,
      required this.time,
      required this.isMessageRead,
      required this.pendingMessage});

  @override
  _ConversationListState createState() => _ConversationListState();
}

class _ConversationListState extends State<ConversationList> {
  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: (){
        Get.to(()=>ChatDetailPage(name: widget.name, image: widget.imageUrl));
      },
      child: Container(
        height: 70,
        width: Get.width,
        decoration: BoxDecoration(
            color: white,
            borderRadius: BorderRadius.circular(16),
            boxShadow: [
              BoxShadow(
                  color: Color(0xffB4B4B4).withOpacity(0.5),
                  offset: Offset(0,1),
                  spreadRadius: 0,
                  blurRadius: 4
              )
            ]
        ),
        // padding: EdgeInsets.only(left: 16,right: 16,top: 10,bottom: 10),
        child: Padding(
          padding: const EdgeInsets.symmetric(horizontal: 20.0),
          child: Row(
            children: <Widget>[
              Expanded(
                child: Row(
                  children: <Widget>[
                    CircleAvatar(
                      backgroundImage: AssetImage(widget.imageUrl),
                      radius: 20,
                    ),
                    SizedBox(width: 16,),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: <Widget>[
                        Text(widget.name, style: TextStyle(fontSize: 14,color: black01,fontFamily: "RobotoBold"),),
                        SizedBox(height: 6,),
                        widget.isMessageRead?Row(children: [
                          SvgPicture.asset(messageSeen),
                          SizedBox(width: 5,),
                          Text(widget.messageText,style: TextStyle(fontSize: 14,color: black3C, fontFamily: "RobotoRegular"),),
                        ],):Text(widget.messageText,style: TextStyle(fontSize: 14,color: black3C, fontFamily: "RobotoRegular"),),
                      ],
                    ),
                  ],
                ),
              ),
              widget.pendingMessage>0?Column(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  Text(widget.time,style: TextStyle(fontSize: 12,color: black00,fontFamily: "RobotoRegular"),),
                  SizedBox(height: 5,),
                  CircleAvatar(
                    radius: 8,
                    backgroundColor: blue,
                    child: Text(widget.pendingMessage.toString(),style: TextStyle(fontFamily: "RobotoRegular",color: white,fontSize: 10),),
                  )
                ],
              ):Text(widget.time,style: TextStyle(fontSize: 12,color: black00,fontFamily: "RobotoRegular"),),
            ],
          ),
        ),
      ),
    );
  }
}

class ChatPage extends StatelessWidget {
  const ChatPage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: ScrollConfiguration(
        behavior: MyBehavior(),
        child: ListView.builder(
          itemCount: chatUsers.length,
          shrinkWrap: true,
          padding: EdgeInsets.only(top: 16),
          itemBuilder: (context, index){
            return Padding(
              padding: EdgeInsets.only(left: 15,right: 15,bottom: 8),
              child: ConversationList(
                name: chatUsers[index].name,
                messageText: chatUsers[index].messageText,
                imageUrl: chatUsers[index].imageURL,
                time: chatUsers[index].time,
                isMessageRead: (index == 0 || index == 2||index == 3||index == 5||index == 6)?true:false,
                pendingMessage: chatUsers[index].pendingMessage,
              ),
            );
          },
        ),
      ),
    );
  }
}

